/**
 * @copyright   2016-2018, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */
import React from 'react';
import PropTypes from 'prop-types';
import { MarkupProps } from './Markup';
import { FilterInterface } from './Filter';
import { MatcherInterface } from './Matcher';
import { AfterParseCallback, BeforeParseCallback, TransformCallback } from './types';
export interface InterweaveProps extends MarkupProps {
    /** Support all the props used by matchers. */
    [prop: string]: any;
    /** Disable all filters from running. */
    disableFilters?: boolean;
    /** Disable all matches from running. */
    disableMatchers?: boolean;
    /** List of filters to apply to the content. */
    filters?: FilterInterface[];
    /** List of matchers to apply to the content. */
    matchers?: MatcherInterface<any>[];
    /** Callback fired after parsing ends. Must return an array of React nodes. */
    onAfterParse?: AfterParseCallback<InterweaveProps> | null;
    /** Callback fired beore parsing begins. Must return a string. */
    onBeforeParse?: BeforeParseCallback<InterweaveProps> | null;
    /** Transformer ran on each HTML element. Return a new element, null to remove current element, or undefined to do nothing. */
    transform?: TransformCallback | null;
}
export default class Interweave extends React.PureComponent<InterweaveProps> {
    static propTypes: {
        content: PropTypes.Requireable<any>;
        disableFilters: PropTypes.Requireable<any>;
        disableLineBreaks: PropTypes.Requireable<any>;
        disableMatchers: PropTypes.Requireable<any>;
        disableWhitelist: PropTypes.Requireable<any>;
        emptyContent: PropTypes.Requireable<any>;
        filters: PropTypes.Requireable<any>;
        matchers: PropTypes.Requireable<any>;
        noHtml: PropTypes.Requireable<any>;
        noHtmlExceptMatchers: PropTypes.Requireable<any>;
        onAfterParse: PropTypes.Requireable<any>;
        onBeforeParse: PropTypes.Requireable<any>;
        tagName: PropTypes.Requireable<any>;
        transform: PropTypes.Requireable<any>;
    };
    static defaultProps: {
        content: string;
        disableFilters: boolean;
        disableLineBreaks: boolean;
        disableMatchers: boolean;
        disableWhitelist: boolean;
        emptyContent: null;
        filters: never[];
        matchers: never[];
        noHtml: boolean;
        noHtmlExceptMatchers: boolean;
        onAfterParse: null;
        onBeforeParse: null;
        tagName: string;
        transform: null;
    };
    /**
     * Parse the markup and apply hooks.
     */
    parseMarkup(): React.ReactNode;
    /**
     * Render the component by parsing the markup.
     */
    render(): JSX.Element;
}
